@@ -52,6 +52,9 @@ class Job(threading.Thread, sqlobject.SQLObject):
 
         threading.Thread.__init__(self)
         sqlobject.SQLObject.__init__(self, *args, **kwargs)
+        if self.log is None:
+            log = Log(job=self)
+
         self.do_quit = threading.Event()
         self.status_lock = threading.Lock()
 
@@ -120,6 +123,10 @@ class Job(threading.Thread, sqlobject.SQLObject):
                                                      stdin=None,
                                                      stderr=subprocess.STDOUT)
             except Exception, error:
+                build_log.write("\nUnable to execute command \"%s\": %s" %\
+                        (cmd, error))
+                with self.status_lock:
+                    self.status = failed_status
                 state = 1
                 break
             state = proc.poll()
